@@ -8,14 +8,16 @@
 #' @param .data the data.frame that is to be summarized
 #' @param ... variables in the data set that are to be summarized; unquoted names separated by commas (e.g. age, gender, race) or indices. If indices, it needs to be a single vector (e.g. c(1:5, 8, 9:20) instead of 1:5, 8, 9:20). As it is currently, it CANNOT handle both indices and unquoted names simultaneously.
 #' @param splitby the categorical variable to stratify by in formula form (e.g., \code{splitby = ~gender}); not too surprisingly, it requires that the number of levels be > 0
+#' @param row_wise how to calculate percentages for factor variables when \code{splitby != NULL}: if \code{FALSE} calculates percentages by variable within groups; if \code{TRUE} calculates percentages across groups for one level of the factor variable.
 #' @param splitby_labels allows for custom labels of the splitby levels; must match the number of levels of the splitby variable
 #' @param test logical; if set to \code{TRUE} then the appropriate bivariate tests of significance are performed if splitby has more than 1 level
 #' @param test_type has two options: "default" performs the default tests of significance only; "or" also give unadjusted odds ratios as well based on logistic regression (only use if splitby has 2 levels)
 #' @param piping if \code{TRUE} then the table is printed and the original data is passed on. It is very useful in piping situations where one wants the table but wants it to be part of a larger pipe.
-#' @param rounding the number of digits after the decimal; default is 3
+#' @param rounding the number of digits after the decimal for means and SD's; default is 2
 #' @param var_names custom variable names to be printed in the table
 #' @param format_output has three options: 1) "full" provides the table with the type of test, test statistic, and the p-value for each variable; 2) "pvalues" provides the table with the p-values; and 3) "stars" provides the table with stars indicating significance
 #' @param output_type default is "text"; the other options are all format options in the \code{kable()} function in \code{knitr} (e.g., latex, html, markdown, pandoc)
+#' @param format_number default in FALSE; if TRUE, then the numbers are formatted with commas (e.g., 20,000 instead of 20000)
 #' @param NAkeep when sset to \code{TRUE} it also shows how many missing values are in the data for each categorical variable being summarized
 #' @param m_label when \code{NAkeep = TRUE} this provides a label for the missing values in the table
 #' @param booktabs when \code{output_type != "text"}; option is passed to \code{knitr::kable}
@@ -27,7 +29,7 @@
 #' @examples 
 #' ## Ficticious Data ##
 #' library(furniture)
-#' library(dplyr)
+#' library(tidyverse)
 #' 
 #' x  <- runif(1000)
 #' y  <- rnorm(1000)
@@ -60,9 +62,24 @@
 #' @export
 #' @import stats
 #' @importFrom knitr kable
-table1 = function(.data, ..., splitby = NULL, splitby_labels = NULL, test = FALSE, test_type = "default", piping = FALSE,
-                  rounding = 3, var_names = NULL, format_output = "pvalues", output_type = "text", NAkeep = FALSE, m_label = "Missing",
-                  booktabs = TRUE, caption=NULL, align=NULL){
+table1 = function(.data, 
+                  ..., 
+                  splitby = NULL, 
+                  row_wise = FALSE, 
+                  splitby_labels = NULL, 
+                  test = FALSE, 
+                  test_type = "default", 
+                  piping = FALSE,
+                  rounding = 2, 
+                  var_names = NULL, 
+                  format_output = "pvalues", 
+                  output_type = "text", 
+                  format_number = FALSE,
+                  NAkeep = FALSE, 
+                  m_label = "Missing",
+                  booktabs = TRUE, 
+                  caption=NULL, 
+                  align=NULL){
   
   # == # Checks and Data # == #
   .call = match.call()
@@ -73,6 +90,12 @@ table1 = function(.data, ..., splitby = NULL, splitby_labels = NULL, test = FALS
     NAkeep = "no"
   }
   
+  if (format_number){
+    f1 = ","
+  } else {
+    f1 = ""
+  }
+  
   data = table1_(..., d_=.data, .cl=.call)
   d = as.data.frame(data)
   
@@ -116,7 +139,11 @@ table1 = function(.data, ..., splitby = NULL, splitby_labels = NULL, test = FALS
     ## If Factor
     if (is.factor(d[,i])){
       tab[[i]] = tapply(d[,i], d$split, table, useNA=NAkeep)
-      tab2[[i]] = tapply(d[,i], d$split, function(x) round(table(x, useNA=NAkeep)/sum(table(x, useNA=NAkeep)), rounding))
+      if (!row_wise){
+        tab2[[i]] = tapply(d[,i], d$split, function(x) round(table(x, useNA=NAkeep)/sum(table(x, useNA=NAkeep)), 1))
+      } else if (row_wise){
+        tab2[[i]] = tapply(d[,i], d$split, function(x) round(table(x, useNA=NAkeep)/table(d[,i], useNA=NAkeep), 1))
+      }
       if (test)
         tests[[i]] = chisq.test(d$split, d[,i])
       if (test & test_type=="or")
@@ -129,7 +156,7 @@ table1 = function(.data, ..., splitby = NULL, splitby_labels = NULL, test = FALS
         ## Breusch-Pagan Test of Heteroskedasticity (equality of variances)
         comp   = complete.cases(d[,i], d$split)
         resids = resid(lm(d[comp,i] ~ d$split[comp]))^2
-        r2     = summary(lm(resids ~ nhanes$gender[comp]))$r.squared
+        r2     = summary(lm(resids ~ d$split[comp]))$r.squared
         lt     = dchisq(length(resids)*r2, df = length(levels(d$split)))
         if (lt<0.05){
           ## Performs an approximate method of Welch (1951)
@@ -179,10 +206,12 @@ table1 = function(.data, ..., splitby = NULL, splitby_labels = NULL, test = FALS
     for (i in 1:length(levels(d$split))){
       if (is.factor(d[,j])){
         tabX = data.frame(tabX, 
-                          paste0(round(tab[[j]][[i]],2), " (", round(tab2[[j]][[i]]*100,1), "%)"))
+                          paste0(suppressWarnings(formatC(tab[[j]][[i]], big.mark = f1)), " (", 
+                                 suppressWarnings(formatC(tab2[[j]][[i]]*100, digits = 2, format = "f")), "%)"))
       } else if (is.numeric(d[,j])){
         tabX = data.frame(tabX, 
-                          paste0(round(tab[[j]][[i]],2), " (", round(tab2[[j]][[i]],2), ")"))
+                          paste0(suppressWarnings(formatC(tab[[j]][[i]], big.mark = f1, digits = 2, format = "f")), " (", 
+                                 suppressWarnings(formatC(tab2[[j]][[i]], big.mark = f1, digits = 2, format = "f")), ")"))
       }
     }
     
@@ -258,8 +287,8 @@ table1 = function(.data, ..., splitby = NULL, splitby_labels = NULL, test = FALS
     } else if (test & format_output=="stars"){
       n3 = data.frame(names(d)[j], matrix(" ", ncol=length(levels(d$split)), nrow=1),
                       paste( ifelse(tests[[j]]$p.value < 0.001, "***", 
-                                    ifelse(tests[[j]]$p.value < 0.01,  "**", 
-                                           ifelse(tests[[j]]$p.value < 0.05,  "*", "")))))
+                             ifelse(tests[[j]]$p.value < 0.01,  "**", 
+                             ifelse(tests[[j]]$p.value < 0.05,  "*", "")))))
       tabX = data.frame(tabX, "")
       names(tabZ) = names(tabX) = names(n3) = c(" ", levels(d$split), " ")
       tabW = rbind(n3, tabX)
@@ -275,6 +304,8 @@ table1 = function(.data, ..., splitby = NULL, splitby_labels = NULL, test = FALS
   
   # == # Observations # == #
   
+  N = suppressWarnings(formatC(N, big.mark = f1, digits = 0, format = "f"))
+  
   if (format_output=="full" & test){
     N = data.frame("Observations", N, "", "")
     names(N) = c(" ", levels(d$split), "Test", "P-Value")
